Linux-Trace-Devel Archive mirror
 help / color / mirror / Atom feed
From: Steven Rostedt <rostedt@goodmis.org>
To: linux-trace-devel@vger.kernel.org
Cc: Ross Zwisler <zwisler@google.com>,
	Stevie Alvarez <stevie.6strings@gmail.com>,
	"Steven Rostedt (Google)" <rostedt@goodmis.org>
Subject: [PATCH v4 02/20] libtraceeval: Reverse params of copy_traceeval_data()
Date: Thu, 17 Aug 2023 16:45:10 -0400	[thread overview]
Message-ID: <20230817204528.114577-3-rostedt@goodmis.org> (raw)
In-Reply-To: <20230817204528.114577-1-rostedt@goodmis.org>

From: "Steven Rostedt (Google)" <rostedt@goodmis.org>

Most C library functions copy data from "dst", "src" order, but
copy_traceeval_data() does it as "src", "dst", and I already made one bug
because of this. Reverse the order of the copy_traceeval_data()
parameters, and also rename them to match standard library names "dst" and
"src".

Link: https://lore.kernel.org/linux-trace-devel/20230817192926.GA73817@google.com/

Signed-off-by: Steven Rostedt (Google) <rostedt@goodmis.org>
---
 src/histograms.c | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/src/histograms.c b/src/histograms.c
index d22d15238616..071e30e73768 100644
--- a/src/histograms.c
+++ b/src/histograms.c
@@ -560,25 +560,25 @@ static int get_entry(struct traceeval *teval, const union traceeval_data *keys,
 }
 
 /*
  * Copy @orig to @copy with respect to @type.
  *
  * Return 0 on success, -1 on error.
  */
 static int copy_traceeval_data(struct traceeval_type *type,
-				const union traceeval_data *orig,
-				union traceeval_data *copy)
+				union traceeval_data *dst,
+				const union traceeval_data *src)
 {
-	*copy = *orig;
+	*dst = *src;
 
 	if (type->type == TRACEEVAL_TYPE_STRING) {
-		copy->string = NULL;
+		dst->string = NULL;
 
-		if (orig->string)
-			copy->string = strdup(orig->string);
+		if (src->string)
+			dst->string = strdup(src->string);
 		else
 			return 0;
 
-		if (!copy->string)
+		if (!dst->string)
 			return -1;
 	}
 
@@ -621,7 +621,7 @@ static int copy_traceeval_data_set(size_t size, struct traceeval_type *type,
 		return -1;
 
 	for (i = 0; i < size; i++) {
-		if (copy_traceeval_data(type + i, orig + i, (*copy) + i))
+		if (copy_traceeval_data(type + i, (*copy) + i, orig + i))
 			goto fail;
 	}
 
@@ -560,25 +560,25 @@ static int get_entry(struct traceeval *teval, const union traceeval_data *keys,
 
 /*
- * Copy @orig to @copy with respect to @type.
+ * Copy @src to @dst with respect to @type.
  *
  * Return 0 on success, -1 on error.
-- 
2.40.1


  parent reply	other threads:[~2023-08-17 20:46 UTC|newest]

Thread overview: 23+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-08-17 20:45 [PATCH v4 00/20] libtraceeval histogram: Updates Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 01/20] libtraceeval histograms: Fix traceeval_results_release() error message Steven Rostedt
2023-08-17 20:45 ` Steven Rostedt [this message]
2023-08-17 20:45 ` [PATCH v4 03/20] libtraceeval: Rename copy_traceeval_data_set() to dup_traceeval_data() Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 04/20] libtraceeval: Add sample task-eval program Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 05/20] libtraceeval hist: Add pointer and const string types Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 06/20] libtraceeval histogram: Have cmp and release functions be generic Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 07/20] libtraceeval histograms: Add traceeval struct to compare function Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 08/20] libtraceeval histogram: Remove comparing of traceeval and types Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 09/20] libtraceeval: Convert hist array into a hash table Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 10/20] libtraceeval histograms: Move hash functions into their own file Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 11/20] libtraceeval histogram: Label and check keys and values Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 12/20] libtraceeval histogram: Add updating of stats Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 13/20] libtraceeval histogram: Add iterator APIs Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 14/20] libtraceeval histogram: Add data copy callback Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 15/20] libtraceeval histogram: Do the release on updates Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 16/20] libtraceeval histogram: Use stack for old copy in update Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 17/20] libtraceeval histogram: Add traceeval_iterator_sort_custom() Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 18/20] libtraceeval histogram: Have traceeval_query() just give the pointer to results Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 19/20] libtraceeval samples: Update task-eval to use the histogram logic Steven Rostedt
2023-08-17 20:45 ` [PATCH v4 20/20] libtraceeval: Add traceeval_remove() Steven Rostedt
2023-08-17 20:48 ` [PATCH v4 00/20] libtraceeval histogram: Updates Steven Rostedt
2023-08-17 20:59 ` Ross Zwisler

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20230817204528.114577-3-rostedt@goodmis.org \
    --to=rostedt@goodmis.org \
    --cc=linux-trace-devel@vger.kernel.org \
    --cc=stevie.6strings@gmail.com \
    --cc=zwisler@google.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).